==> xl-react-components-0.16.62.tgz: package/app/xl-react-widget/xl-react-widget-redux-table/xl-react-widget-redux-table.js <==
import R from 'ramda';
import React, {PureComponent} from 'react';
import {connect} from 'react-redux';
import PropTypes from 'prop-types';
import {XlReactWidgetTable} from '../xl-react-widget-table/xl-react-widget-table';
import {
    tableFiltersType,
    tableLayoutType,
    tablePagingType,
    tableSortingType
} from '../xl-react-widget-table/xl-react-widget-table-types';
import XlReactWidgetTableFilters from './xl-react-widget-table-filters';
import tableActions from './xl-react-widget-redux-table-actions';
import {getTableById} from './xl-react-widget-table-selectors';

const mapStateToProps = (state, ownProps) => getTableById(state, ownProps.tableId);

const mapDispatchToProps = (dispatch, ownProps) => ({
    onFilterChange: (filter) => dispatch(tableActions.filter(ownProps.tableId, ownProps.fetchDataApi, filter)),
    onPageChange: (page, resultsPerPage) =>
        dispatch(tableActions.paginate(
            ownProps.tableId,
            ownProps.fetchDataApi,
            page,
            resultsPerPage)),
    onSortChange: (name, order) => dispatch(tableActions.sort(ownProps.tableId, ownProps.fetchDataApi, name, order)),
    unmount: () => dispatch(tableActions.unmount(ownProps.tableId))
});

@connect(mapStateToProps, mapDispatchToProps)
export class XlReactWidgetReduxTable extends PureComponent {
    static propTypes = {
        className: PropTypes.string,
        createColumnDefinition: PropTypes.func.isRequired,
        data: PropTypes.array,
        defaultErrorMessage: PropTypes.string.isRequired,
        defaultNoDataText: PropTypes.string.isRequired,
        error: PropTypes.object,
        filters: tableFiltersType,
        filterType: PropTypes.oneOf(['above', 'column', '']).isRequired,
        keyField: PropTypes.any.isRequired,
        layout: tableLayoutType,
        loading: PropTypes.bool,
        loadingMessage: PropTypes.node,
        onFilterChange: PropTypes.func,
        onPageChange: PropTypes.func,
        onRowClick: PropTypes.func,
        onRowDoubleClick: PropTypes.func,
        onSortChange: PropTypes.func,
        paging: tablePagingType,
        register: PropTypes.func,
        selectRow: PropTypes.object.isRequired,
        sorting: tableSortingType,
        tableHeaderClass: PropTypes.string,
        total: PropTypes.number,
        totalClassName: PropTypes.string,
        unmount: PropTypes.func
    };

    static defaultProps = {columnsFilter: {}, data: [], total: 0};

    componentWillUnmount() {
        this.props.unmount();
    }

    handleColumnFilterChange = (change) => {
        this.props.onFilterChange({change, type: 'all'});
    };

    filterConfigFactory = (filters = []) =>
        R.reduce((acc, item) => ({...acc, [item.key]: item.model}), {}, filters);

    render() {
        const {
            className,
            createColumnDefinition,
            data,
            defaultErrorMessage,
            defaultNoDataText,
            error,
            filters,
            filterType,
            keyField,
            layout,
            loading,
            loadingMessage,
            onFilterChange,
            onPageChange,
            onRowClick,
            onRowDoubleClick,
            onSortChange,
            paging,
            register,
            selectRow,
            sorting,
            tableHeaderClass,
            total,
            totalClassName
        } = this.props;

        const columnsFilter = filterType === 'column' ? this.filterConfigFactory(filters) : {};

        return (
            <React.Fragment>
                {filterType === 'above' && <XlReactWidgetTableFilters
                    config={filters}
                    onFilterChange={onFilterChange}
                />}
                <XlReactWidgetTable
                    className={className}
                    createColumnDefinition={createColumnDefinition}
                    data={data}
                    defaultErrorMessage={defaultErrorMessage}
                    defaultNoDataText={defaultNoDataText}
                    error={error}
                    filter={columnsFilter}
                    keyField={keyField}
                    layout={layout}
                    loading={loading}
                    loadingMessage={loadingMessage}
                    onFilterChange={this.handleColumnFilterChange}
                    onPageChange={onPageChange}
                    onRowClick={onRowClick}
                    onRowDoubleClick={onRowDoubleClick}
                    onSortChange={onSortChange}
                    paging={paging}
                    register={register}
                    selectRow={selectRow}
                    sorting={sorting}
                    tableHeaderClass={tableHeaderClass}
                    total={total}
                    totalClassName={totalClassName}
                />
            </React.Fragment>
        );
    }
}

==> xl-react-components-0.21.16.tgz: package/app/xl-react-widget/xl-react-widget-redux-table/xl-react-widget-redux-table.js <==
import R from 'ramda';
import React, {PureComponent} from 'react';
import {connect} from 'react-redux';
import classNames from 'classnames';
import PropTypes from 'prop-types';
import {XlReactWidgetTable} from '../xl-react-widget-table/xl-react-widget-table';
import {
    newStateTransformerType,
    tableFiltersType,
    tableLayoutType,
    tablePagingType,
    tableSortingType
} from '../xl-react-widget-table/xl-react-widget-table-types';
import {xlReactWidgetTableFilterStyle} from './xl-react-widget-table-filter-type';
import XlReactWidgetTableFilters from './xl-react-widget-table-filters';
import tableActions from './xl-react-widget-redux-table-actions';
import {getTableById} from './xl-react-widget-table-selectors';

const mapStateToProps = (state, ownProps) => getTableById(state, ownProps.tableId);

const mapDispatchToProps = (dispatch, ownProps) => ({
    onFilterChange: (filter) => dispatch(tableActions.filter(ownProps.tableId, ownProps.fetchDataApi, filter)),
    onPageChange: (page, resultsPerPage) =>
        dispatch(tableActions.paginate(
            ownProps.tableId,
            ownProps.fetchDataApi,
            page,
            resultsPerPage)),
    onSortChange: (name, order) => dispatch(tableActions.sort(ownProps.tableId, ownProps.fetchDataApi, name, order)),
    unmount: () => dispatch(tableActions.unmount(ownProps.tableId))
});

@connect(mapStateToProps, mapDispatchToProps)
export class XlReactWidgetReduxTable extends PureComponent {
    static propTypes = {
        autoCleanup: PropTypes.bool,
        className: PropTypes.string,
        createColumnDefinition: PropTypes.func.isRequired,
        data: PropTypes.array,
        defaultErrorMessage: PropTypes.string.isRequired,
        defaultNoDataText: PropTypes.string.isRequired,
        displayOnlyLabelIfNoData: PropTypes.bool,
        error: PropTypes.object,
        filterComponentProps: PropTypes.object,
        filters: tableFiltersType,
        filterType: PropTypes.oneOf([
            xlReactWidgetTableFilterStyle.ABOVE,
            xlReactWidgetTableFilterStyle.COLUMN,
            ''
        ]).isRequired,
        keyField: PropTypes.any.isRequired,
        layout: tableLayoutType,
        loading: PropTypes.bool,
        loadingMessage: PropTypes.node,
        onFilterChange: PropTypes.func,
        onPageChange: PropTypes.func,
        onRowClick: PropTypes.func,
        onRowDoubleClick: PropTypes.func,
        onSortChange: PropTypes.func,
        paging: tablePagingType,
        register: PropTypes.func,
        selectRow: PropTypes.object.isRequired,
        showFilters: PropTypes.bool,
        sorting: tableSortingType,
        tableHeaderClass: PropTypes.string,
        total: PropTypes.number,
        totalClassName: PropTypes.string,
        transformNewStateOnChange: newStateTransformerType,
        unmount: PropTypes.func
    };

    static defaultProps = {
        autoCleanup: true,
        columnsFilter: {},
        data: [],
        total: 0
    };

    componentWillUnmount() {
        const {autoCleanup, unmount} = this.props;
        if (autoCleanup) {
            unmount();
        }
    }

    handleColumnFilterChange = (change) => {
        this.props.onFilterChange({change, type: 'all'});
    };

    filterConfigFactory = (filters = []) =>
        R.reduce((acc, item) => ({...acc, [item.key]: item.model}), {}, filters);

    render() {
        const {
            className,
            createColumnDefinition,
            data,
            defaultErrorMessage,
            defaultNoDataText,
            displayOnlyLabelIfNoData,
            error,
            filterComponentProps,
            filters,
            filterType,
            keyField,
            layout,
            loading,
            loadingMessage,
            onFilterChange,
            onPageChange,
            onRowClick,
            onRowDoubleClick,
            onSortChange,
            paging,
            register,
            selectRow,
            showFilters,
            sorting,
            tableHeaderClass,
            total,
            totalClassName,
            transformNewStateOnChange
        } = this.props;

        const columnsFilter = filterType === 'column' ? this.filterConfigFactory(filters) : {};

        const shouldNotDisplayTable = () => displayOnlyLabelIfNoData && R.length(data) === 0;

        return shouldNotDisplayTable() ?
            <span className={classNames(className, 'no-data')}>{defaultNoDataText}</span> :
            <React.Fragment>
                {filterType === 'above' && <XlReactWidgetTableFilters
                    config={filters}
                    filterProps={filterComponentProps}
                    onFilterChange={onFilterChange}
                    showFilters={showFilters}
                />}
                <XlReactWidgetTable
                    className={className}
                    createColumnDefinition={createColumnDefinition}
                    data={data}
                    defaultErrorMessage={defaultErrorMessage}
                    defaultNoDataText={defaultNoDataText}
                    error={error}
                    filter={columnsFilter}
                    keyField={keyField}
                    layout={layout}
                    loading={loading}
                    loadingMessage={loadingMessage}
                    onFilterChange={this.handleColumnFilterChange}
                    onPageChange={onPageChange}
                    onRowClick={onRowClick}
                    onRowDoubleClick={onRowDoubleClick}
                    onSortChange={onSortChange}
                    paging={paging}
                    register={register}
                    selectRow={selectRow}
                    sorting={sorting}
                    tableHeaderClass={tableHeaderClass}
                    total={total}
                    totalClassName={totalClassName}
                    transformNewStateOnChange={transformNewStateOnChange}
                />
            </React.Fragment>;
    }
}
